@@ -8,7 +8,7 @@
 **     COPYRIGHT
 **
 ** Exceptions:
-**     PicosatError
+**     Error
 **
 ** Interface Functions:
 **     satisfy_one
@@ -21,11 +21,11 @@
 #include "picosat.h"
 
 /*
-** Python exception definition: picosat.PicosatError
+** Python exception definition: picosat.Error
 */
-PyDoc_STRVAR(_picosat_error_docstring, "PicoSAT Error");
+PyDoc_STRVAR(_error_docstring, "PicoSAT Error");
 
-static PyObject *_picosat_error;
+static PyObject *_error;
 
 /* Pass these functions to picosat_minit to use Python's memory manager. */
 inline static void *
@@ -149,12 +149,8 @@ _add_assumptions(PicoSAT *picosat, PyObject *assumptions)
             goto decref_pylits;
         }
         lit = PyLong_AsLong(pylit);
-        if (lit == 0 || abs(lit) > nvars) {
-            PyErr_Format(
-                PyExc_ValueError,
-                "expected assumption literal in range [-%d, 0), (0, %d], got: %d",
-                nvars, nvars, lit
-            );
+        if (lit == 0) {
+            PyErr_SetString(PyExc_ValueError, "expected nonzero assumption literal");
             goto decref_pylits;
         }
 
@@ -262,6 +258,9 @@ PyDoc_STRVAR(_satisfy_one_docstring,
 \n\
     clauses : iter of iter of (nonzero) int\n\
         The CNF clauses\n\
+\n\
+    assumptions : iter of (nonzero) int\n\
+        Add assumptions (unit clauses) to the CNF\n\
 \n\
     verbosity : int, optional\n\
         Set verbosity level. A verbosity level of 1 and above prints more and\n\
@@ -281,9 +280,6 @@ PyDoc_STRVAR(_satisfy_one_docstring,
     decision_limit : int\n\
         Set a limit on the number of decisions. A negative value sets no\n\
         decision limit.\n\
-\n\
-    assumptions : iter of (nonzero) int\n\
-        Add assumptions (unit clauses) to the CNF\n\
 \n\
     Returns\n\
     -------\n\
@@ -299,8 +295,8 @@ _satisfy_one(PyObject *self, PyObject *args, PyObject *kwargs)
 {
     static char *keywords[] = {
         "nvars", "clauses",
-        "verbosity", "default_phase", "propagation_limit", "decision_limit",
         "assumptions",
+        "verbosity", "default_phase", "propagation_limit", "decision_limit",
         NULL
     };
 
@@ -310,11 +306,11 @@ _satisfy_one(PyObject *self, PyObject *args, PyObject *kwargs)
     /* PicoSAT input parameters */
     int nvars = 0;
     PyObject *clauses;
+    PyObject *assumptions = NULL;
     int verbosity = 0;
     int default_phase = 2; /* Jeroslow-Wang */
     int propagation_limit = -1;
     int decision_limit = -1;
-    PyObject *assumptions = NULL;
 
     /* PicoSAT return value */
     int result;
@@ -323,10 +319,10 @@ _satisfy_one(PyObject *self, PyObject *args, PyObject *kwargs)
     PyObject *pyret = NULL;
 
     if (!PyArg_ParseTupleAndKeywords(
-            args, kwargs, "iO|iiiiO:satisfy_one", keywords,
+            args, kwargs, "iO|Oiiii:satisfy_one", keywords,
             &nvars, &clauses,
-            &verbosity, &default_phase, &propagation_limit, &decision_limit,
-            &assumptions))
+            &assumptions,
+            &verbosity, &default_phase, &propagation_limit, &decision_limit))
         goto done;
 
     if (nvars < 0) {
@@ -340,7 +336,7 @@ _satisfy_one(PyObject *self, PyObject *args, PyObject *kwargs)
 
     picosat = picosat_minit(NULL, _pymalloc, _pyrealloc, _pyfree);
     if (picosat == NULL) {
-        PyErr_SetString(_picosat_error, "could not initialize PicoSAT");
+        PyErr_SetString(_error, "could not initialize PicoSAT");
         goto done;
     }
 
@@ -374,10 +370,10 @@ _satisfy_one(PyObject *self, PyObject *args, PyObject *kwargs)
         pyret = _get_soln(picosat);
     }
     else if (result == PICOSAT_UNKNOWN) {
-        PyErr_SetString(_picosat_error, "PicoSAT returned UNKNOWN");
+        PyErr_SetString(_error, "PicoSAT returned UNKNOWN");
     }
     else {
-        PyErr_Format(_picosat_error, "PicoSAT returned: %d", result);
+        PyErr_Format(_error, "PicoSAT returned: %d", result);
     }
 
 reset_picosat:
@@ -480,7 +476,7 @@ _satisfy_all_new(PyTypeObject *cls, PyObject *args, PyObject *kwargs)
 
     picosat = picosat_minit(NULL, _pymalloc, _pyrealloc, _pyfree);
     if (picosat == NULL) {
-        PyErr_SetString(_picosat_error, "could not initialize PicoSAT");
+        PyErr_SetString(_error, "could not initialize PicoSAT");
         goto error;
     }
 
@@ -561,7 +557,7 @@ _satisfy_all_next(_satisfy_all_state *state)
         /* No more solutions */
     }
     else {
-        PyErr_Format(_picosat_error, "PicoSAT returned: %d", result);
+        PyErr_Format(_error, "PicoSAT returned: %d", result);
     }
 
     return pyret;
@@ -623,7 +619,7 @@ Constants:\n\
     COPYRIGHT\n\
 \n\
 Exceptions:\n\
-    PicosatError\n\
+    Error\n\
 \n\
 Interface Functions:\n\
     satisfy_one\n\
@@ -664,16 +660,16 @@ PyInit_picosat(void)
     if (PyModule_AddStringConstant(pymodule, "COPYRIGHT", picosat_copyright()) < 0)
         goto error;
 
-    /* Create PicosatError */
-    _picosat_error = PyErr_NewExceptionWithDoc("picosat.PicosatError",
-                                               _picosat_error_docstring,
-                                               NULL, NULL);
-    if (_picosat_error == NULL)
+    /* Create Error */
+    _error = PyErr_NewExceptionWithDoc("picosat.Error",
+                                       _error_docstring,
+                                       NULL, NULL);
+    if (_error == NULL)
         goto error;
 
-    Py_INCREF(_picosat_error);
-    if (PyModule_AddObject(pymodule, "PicosatError", _picosat_error) < 0) {
-        Py_DECREF(_picosat_error);
+    Py_INCREF(_error);
+    if (PyModule_AddObject(pymodule, "Error", _error) < 0) {
+        Py_DECREF(_error);
         goto error;
     }
 
